<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>Bubble</name>
    <message>
        <location filename="../dde-osd/src/notification/bubble.cpp" line="325"/>
        <source>1 new message</source>
        <translation>1 mensaje nuevo</translation>
    </message>
</context>
<context>
    <name>BubbleItem</name>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="232"/>
        <source>Just Now</source>
        <translation>Ahora mismo</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="234"/>
        <source>%1 minutes ago</source>
        <translation>Hace %1 minutos</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="236"/>
        <source>%1 hours ago</source>
        <translation>Hace %1 horas</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/notification-center/bubbleitem.cpp" line="239"/>
        <source>Yesterday </source>
        <translation>Ayer </translation>
    </message>
</context>
<context>
    <name>Content</name>
    <message>
        <location filename="../dde-license-dialog/src/content.cpp" line="272"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../dde-license-dialog/src/content.cpp" line="273"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>DMemoryWarningDialog</name>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="49"/>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="88"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="51"/>
        <source>Release</source>
        <translation>Liberar</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="55"/>
        <source>This application will be ended, please make sure your data has been saved!</source>
        <translation>La aplicación se finalizará, ¡asegúrese de guardar sus datos, por favor!</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="56"/>
        <source>Please save your document, text and spreadsheet</source>
        <translation>Por favor guarde sus documentos, textos y diapositivas</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="89"/>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="110"/>
        <source>Insufficient system memory, please end some applications to avoid getting stuck.</source>
        <translation>Memoria del sistema insuficiente, por favor cierre algunas aplicaciones para evitar cuelgues.</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="222"/>
        <source>Continue to run %1, %2MB memory is required</source>
        <translation>Continuar la ejecución de %1, requiere %2MB de memoria</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="225"/>
        <source>Continue to open browser tab, %1MB memory is required</source>
        <translation>Continuar la apertura de la pestaña del navegador, requiere de %1MB de memoria</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="228"/>
        <source>To continue the operation, %1MB memory is required</source>
        <translation>Continuar la operación, requiere de %1MB de memoria</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="234"/>
        <source>Your current memory is sufficient enough, continue to run %1?</source>
        <translation>Su memoria actual es insuficiente, ¿continuará la ejecución de %1?</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="237"/>
        <source>Your current memory is sufficient enough, continue to open browser tab?</source>
        <translation>Su memoria actual es insuficiente, ¿continuará la apertura de la pestaña del navegador?</translation>
    </message>
    <message>
        <location filename="../dmemory-warning-dialog/src/dmemorywarningdialog.cpp" line="240"/>
        <source>Your current memory is sufficient enough, continue the operation?</source>
        <translation>Su memoria actual es insuficiente, ¿continuará la operación?</translation>
    </message>
</context>
<context>
    <name>DisplayModeProvider</name>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="292"/>
        <source>Only on %1</source>
        <translation>Solo mostrada en %1</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="294"/>
        <source>Duplicate</source>
        <translation>Duplicada</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/displaymodeprovider.cpp" line="296"/>
        <source>Extend</source>
        <translation>Extendida</translation>
    </message>
</context>
<context>
    <name>KBLayoutIndicator</name>
    <message>
        <location filename="../dde-osd/src/kblayoutindicator.cpp" line="161"/>
        <source>Add keyboard layout</source>
        <translation>Añadir distribución de teclado</translation>
    </message>
</context>
<context>
    <name>NetworkSecretDialog</name>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="107"/>
        <source>Password required to connect &lt;font color=&quot;%1&quot;&gt;%2&lt;/font&gt;</source>
        <translation>Se requiere contraseña para conectar &lt;font color=&quot;%1&quot;&gt;%2&lt;/font&gt;</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="179"/>
        <source>Wrong password, please enter again!</source>
        <translation>Contraseña incorrecta, ¡por favor ingrese de nuevo!</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="116"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="116"/>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
</context>
<context>
    <name>NotifyCenterWidget</name>
    <message>
        <location filename="../dde-osd/src/notification-center/notifycenterwidget.cpp" line="97"/>
        <source>Notification Center</source>
        <translation>Centro de notificaciones</translation>
    </message>
</context>
<context>
    <name>NotifyWidget</name>
    <message>
        <location filename="../dde-osd/src/notification-center/notifywidget.cpp" line="40"/>
        <source>No system notifications</source>
        <translation>Sin notificaciones del sistema</translation>
    </message>
</context>
<context>
    <name>OSDProvider</name>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="138"/>
        <source>Fn toggle</source>
        <translation>Fn conmutador</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="125"/>
        <source>WLAN on</source>
        <translation>WLAN encendido</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="126"/>
        <source>WLAN off</source>
        <translation>WLAN apagado</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="128"/>
        <source>Caps Lock on</source>
        <translation>Bloqueo de mayúsculas activado</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="129"/>
        <source>Caps Lock off</source>
        <translation>Bloqueo de mayúsculas desactivado</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="131"/>
        <source>Numeric keypad on</source>
        <translation>Teclado numérico encendido</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="132"/>
        <source>Numeric keypad off</source>
        <translation>Teclado numérico apagado</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="134"/>
        <source>Touchpad on</source>
        <translation>Panel táctil encendido</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="135"/>
        <source>Touchpad off</source>
        <translation>Panel táctil apagado</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="136"/>
        <source>Touchpad toggle</source>
        <translation>Alternancia del panel táctil</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="140"/>
        <source>Airplane mode on</source>
        <translation>Modo avión activado</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="141"/>
        <source>Airplane mode off</source>
        <translation>Modo avión desactivado</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="143"/>
        <source>Mute on</source>
        <translation>Silencio activado</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="144"/>
        <source>Mute off</source>
        <translation>Silencio desactivado</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="146"/>
        <source>Balanced power</source>
        <translation>Potencia equilibrada</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="147"/>
        <source>Power saver</source>
        <translation>Ahorro de energía</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="148"/>
        <source>High performance</source>
        <translation>Alto rendimiento</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="150"/>
        <source>Window effect enabled</source>
        <translation>Efectos de ventana activados</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="151"/>
        <source>Window effect disabled</source>
        <translation>Efectos de ventana desactivados</translation>
    </message>
    <message>
        <location filename="../dde-osd/src/osdprovider.cpp" line="152"/>
        <source>Failed to enable window effects</source>
        <translation>Error al activar efectos de ventana</translation>
    </message>
</context>
<context>
    <name>PasswordWidget</name>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="57"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="146"/>
        <source>Passwords do not match</source>
        <translation>Las contraseñas no coinciden</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="65"/>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation>La pista es visible para todos. No incluya la contraseña.</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="86"/>
        <source>New Password</source>
        <translation>Nueva contraseña:</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="120"/>
        <source>Repeat Password</source>
        <translation>Repita la contraseña</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="128"/>
        <source>Password Hint</source>
        <translation>Pista de contraseña</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="137"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="138"/>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="139"/>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="221"/>
        <source>Strong</source>
        <translation>Fuerte</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="231"/>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="240"/>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="253"/>
        <source>A stronger password is recommended: more than 8 characters, and contains 3 of the four character types: lowercase letters, uppercase letters, numbers, and symbols.</source>
        <translation>Se recomienda una contraseña más fuerte: más de 8 caracteres, y que contenga 3 de los cuatro tipos de caracteres: letras minúsculas, letras mayúsculas, números y símbolos.</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="244"/>
        <source>Weak</source>
        <translation>Débil</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/passwordwidget.cpp" line="255"/>
        <source>Error occurred when reading the configuration files of password rules!</source>
        <translation>Se ha producido un error al leer los archivos de configuración de las reglas de contraseña.</translation>
    </message>
</context>
<context>
    <name>PinCodeDialog</name>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="40"/>
        <source>The PIN for connecting to the Bluetooth device is:</source>
        <translation>El PIN para conectar el dispositivo Bluetooth es:</translation>
    </message>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="49"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../dde-bluetooth-dialog/src/pincodedialog.cpp" line="51"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>ProcessInfoModel</name>
    <message>
        <location filename="../dmemory-warning-dialog/src/processinfomodel.cpp" line="111"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="76"/>
        <source>Password cannot be empty</source>
        <translation>La contraseña no puede estar vacía</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="77"/>
        <source>Password must have at least %1 characters</source>
        <translation>La contraseña debe tener al menos %1 caracteres</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="78"/>
        <source>Password must be no more than %1 characters</source>
        <translation>La contraseña no debe tener más de %1 caracteres</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="79"/>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>La contraseña debe contener letras latinas (sensible a mayúsculas), números o símbolos (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="80"/>
        <source>No more than %1 palindrome characters please</source>
        <translation>No más de %1 caracteres palíndromos</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="81"/>
        <source>No more than %1 monotonic characters please</source>
        <translation>No más de %1 caracteres monótonos por favor</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="82"/>
        <source>No more than %1 repeating characters please</source>
        <translation>No más de %1 caracteres repetidos, por favor</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="87"/>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>La contraseña debe contener letras mayúsculas, minúsculas, números y símbolos (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="88"/>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>La contraseña no debe contener más de 4 caracteres palíndromos</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="89"/>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="92"/>
        <source>Do not use common words and combinations as password</source>
        <translation>No use palabras o combinaciones comunes como contraseña</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="90"/>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="91"/>
        <source>Create a strong password please</source>
        <translation>Por favor, cree una contraseña fuerte</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/pwqualitymanager.cpp" line="97"/>
        <source>It does not meet password rules</source>
        <translation>No cumple con las reglas de contraseñas</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="43"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="49"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="59"/>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="44"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="45"/>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="46"/>
        <source>Key</source>
        <translation>Clave</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="47"/>
        <source>key</source>
        <translation>Clave</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="55"/>
        <source>Private Pwd</source>
        <translation>Contraseña privada</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="58"/>
        <source>Proxy Password</source>
        <translation>Contraseña del proxy</translation>
    </message>
    <message>
        <location filename="../dnetwork-secret-dialog/src/networksecretdialog.cpp" line="60"/>
        <source>Group Password</source>
        <translation>Contraseña del grupo</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/utils.h" line="71"/>
        <source>It cannot be empty</source>
        <translation>No puede estar vacío</translation>
    </message>
</context>
<context>
    <name>ResetPasswordDialog</name>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="110"/>
        <source>Resetting the password will clear the data stored in the keyring</source>
        <translation>Restablecer la contraseña borrará los datos almacenados en el llavero.</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="112"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="168"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="210"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="121"/>
        <source>Security Questions</source>
        <translation>Preguntas de seguridad</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="156"/>
        <source>Reset Password</source>
        <translation>Restablecer contraseña</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="157"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="198"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="160"/>
        <source>Reset Password By Union ID</source>
        <translation>Restablecer contraseña de Union ID</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="161"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="195"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="198"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="206"/>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="213"/>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="167"/>
        <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
        <translation>El restablecimiento de la contraseña borrará los datos almacenados en su llavero, y deberá volver a conectarse, por favor, guarde los archivos con antelación.</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="168"/>
        <source>Confirm and Reset</source>
        <translation>Confirmar y restablecer</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/resetpassworddialog.cpp" line="264"/>
        <source>Successfully reset, please log in and unlock with the new password</source>
        <translation>Restablecido exitosamente, por favor inicie sesión y desbloquee con la nueva contraseña</translation>
    </message>
</context>
<context>
    <name>SecurityQuestionsWidget</name>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="127"/>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="128"/>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="129"/>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="131"/>
        <source>What&apos;s the name of the city where you were born?</source>
        <translation>¿Cómo se llama la ciudad donde naciste?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="132"/>
        <source>What&apos;s the name of the first school you attended?</source>
        <translation>¿Cómo se llama la primera escuela a la que asististe?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="133"/>
        <source>Who do you love the most in this world?</source>
        <translation>¿A quién amas más en este mundo?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="134"/>
        <source>What&apos;s your favorite animal?</source>
        <translation>¿Cuál es su animal favorito?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="135"/>
        <source>What&apos;s your favorite song?</source>
        <translation>¿Cuál es su canción favorita?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="136"/>
        <source>What&apos;s your nickname?</source>
        <translation>¿Cuál es su apodo?</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="186"/>
        <source>Wrong answer</source>
        <translation>Respuesta incorrecta</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/securityquestionswidget.cpp" line="201"/>
        <source>Keep the answer under 30 characters</source>
        <translation>Mantenga la respuesta por debajo de los 30 caracteres</translation>
    </message>
</context>
<context>
    <name>SuspendDialog</name>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="39"/>
        <source>External monitor detected, suspend?</source>
        <translation>Monitor externo detectado, ¿suspender?</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="39"/>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="65"/>
        <source>%1s</source>
        <translation>%1s</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../dde-suspend-dialog/src/suspenddialog.cpp" line="54"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
</context>
<context>
    <name>TouchscreenSetting</name>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="45"/>
        <source>Select your touch screen</source>
        <translation>Seleccione su pantalla táctil</translation>
    </message>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="55"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../dde-touchscreen-dialog/src/touchscreensetting.cpp" line="56"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>UnionIDWidget</name>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="63"/>
        <source>Phone/Email</source>
        <translation>Teléfono/Correo electrónico</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="69"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="136"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="289"/>
        <source>Get Code</source>
        <translation>Obtener código</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="89"/>
        <source>Connecting to the Internet...</source>
        <translation>Conectándose a Internet...</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="101"/>
        <source>The user account is not linked to Union ID</source>
        <translation>La cuenta de usuario no está vinculada al ID de la Unión</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="114"/>
        <source>Network disconnected, please retry after connected</source>
        <translation>Red desconectada, por favor vuelva a intentarlo después de conectarse</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="134"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="135"/>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="170"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="185"/>
        <source>Phone/Email format is incorrect</source>
        <translation>El formato del teléfono/correo electrónico es incorrecto</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="239"/>
        <source>System error</source>
        <translation>Error del sistema</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="241"/>
        <source>Login expired, please sign in to the Union ID again</source>
        <translation>El inicio de sesión ha caducado, inicie la sesión nuevamente en Union ID</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="243"/>
        <source>Network error</source>
        <translation>Error de red</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="245"/>
        <source>You have reached the number limit to get the code today</source>
        <translation>Ha alcanzado el límite de números para conseguir el código hoy</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="246"/>
        <source>The Union ID is not linked to a user account</source>
        <translation>El ID de la Unión no está vinculado a una cuenta de usuario</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="255"/>
        <source>It cannot be empty</source>
        <translation>No puede estar vacío</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="292"/>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="334"/>
        <source>Resend (%1s)</source>
        <translation>Reenviar (%1s)</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="353"/>
        <source>Failed to get the code</source>
        <translation>No se ha podido obtener el código</translation>
    </message>
    <message>
        <location filename="../reset-password-dialog/unionidwidget.cpp" line="376"/>
        <source>Wrong verification code</source>
        <translation>Código de verificación erróneo</translation>
    </message>
</context>
<context>
    <name>UpdateContent</name>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="45"/>
        <source>Welcome, system updated successfully</source>
        <translation>Bienvenido, el sistema se actualizó con éxito</translation>
    </message>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="46"/>
        <source>Current Edition:</source>
        <translation>Edición actual:</translation>
    </message>
    <message>
        <location filename="../dde-welcome/src/updatecontent.cpp" line="47"/>
        <source>Enter</source>
        <translation>Entrar</translation>
    </message>
</context>
<context>
    <name>WMChooser</name>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="57"/>
        <source>Effect Mode</source>
        <translation>Activar efectos</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="60"/>
        <source>Normal Mode</source>
        <translation>Desactivar efectos</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="68"/>
        <source>It has detected that you are using a virtual machine, which will affect the system performance and operation experience, for a smooth experience, Normal Mode is recommended</source>
        <translation>Esta es una máquina virtual. Esto afectará el rendimiento. Para disfrutar una mejor experiencia, se recomienda no usar efectos.</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="71"/>
        <source>Effect Mode: Have a delicate experience. Normal Mode: Enjoy the fast performance</source>
        <translation>Con efectos tendrá una experiencia agradable.
Sin efectos disfrutará de un mayor rendimiento.</translation>
    </message>
    <message>
        <location filename="../dde-wm-chooser/src/wmchooser.cpp" line="64"/>
        <source>Friendly Reminder</source>
        <translation>Recordatorio amistoso</translation>
    </message>
</context>
<context>
    <name>WarningDialog</name>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="38"/>
        <source>Kindly Reminder</source>
        <translation>Recordatorio amistoso</translation>
    </message>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="39"/>
        <source>This application cannot run without window effect</source>
        <translation>Esta aplicación no puede ser ejecutada sin efectos de ventana</translation>
    </message>
    <message>
        <location filename="../dde-warning-dialog/src/warningdialog.cpp" line="43"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../dde-lowpower/src/window.cpp" line="41"/>
        <source>Low battery, please plug in</source>
        <translation>Batería baja. Por favor conecte a una toma eléctrica</translation>
    </message>
</context>
</TS>